﻿<!-- BDS: Modified from the existing Bakery Template. For HTML5 Forms markup and polyfilling code, scroll down -->
@Code
Page.Title = "Place Your Order"

	Dim db = Database.Open("bakery")
	Dim productId = UrlData(0).AsInt()
	Dim product = db.QuerySingle("SELECT * FROM PRODUCTS WHERE ID = @0", productId)

	If product Is Nothing Then
		Response.Redirect("~/")
	End If

	If IsPost Then
		Dim name = Request("orderName")
		Dim email = Request("orderEmail")
		Dim shipping = Request("orderShipping")

		'If there is no error try to process order
		If ModelState.Count = 0 Then
			Dim body = "Thank you, we have received your order for " & Request("orderQty") & " unit(s) of " & product.Name & "!<br/>"
			Dim orderShipping = Request("orderShipping")
			Dim customerEmail = Request("orderEmail")
			If Not orderShipping.IsEmpty() Then
				'Replace carriage returns with HTML breaks for HTML mail
				Dim formattedOrder = orderShipping.Replace(vbCrLf, "<br/>")
				body &= "Your address is: <br/>" & formattedOrder & "<br/>"
			End If
			body &= "Your total is $" & product.Price * Request("orderQty").AsDecimal() & ".<br/>"
			body &= "We will contact you if we have questions about your order.  Thanks!<br/>"

			'SMTP Configuration for Hotmail
			WebMail.SmtpServer = "smtp.live.com"
			WebMail.SmtpPort = 25
			WebMail.EnableSsl = True

			'Enter your Hotmail credentials for UserName/Password and a "From" address for the e-mail
			WebMail.UserName = ""
			WebMail.Password = ""
			WebMail.From = ""

			If WebMail.UserName.IsEmpty() OrElse WebMail.Password.IsEmpty() OrElse WebMail.From.IsEmpty() Then
				Response.Redirect("~/OrderSuccess?NoEmail=1")
			Else
				Try
					WebMail.Send(to:= customerEmail, subject:= "Fourth Coffee - New Order", body:= body)
					Response.Redirect("~/OrderSuccess")
				Catch
					ModelState.AddFormError("There was an error and your order could not be processed at this time")
				End Try
			End If
		End If
	End If
End Code
<ol id="orderProcess">
    <li><span class="step-number">1</span>Choose Item</li>
    <li class="current"><span class="step-number">2</span>Details &amp; Submit</li>
    <li><span class="step-number">3</span>Receipt</li>
</ol>
<h1>Place Your Order: @product.Name</h1>
@Html.ValidationSummary(excludeFieldErrors:= True)
<form action="" method="post" id="orderForm">
    <fieldset class="no-legend">
        <legend>Place Your Order</legend>
        <img class="product-image order-image" src="@Href("~/Images/Products/Thumbnails/" + product.ImageName)" alt="Image of @product.Name"/>
        <ol>
            <li class="name" >
                <label for="orderName">Your Name</label>
                <input type="text" class="field" id="orderName" required autofocus placeholder="ex. Hugo Reyes" />                
            </li>
            <li class="email">
                <label for="orderEmail">Your Email Address</label>
                <input type="email"  class="field" id="orderEmail" required placeholder="ex. name@domain.com" />
            </li>
            <li class="website">
                <label for="orderWebsite">Your Web Site</label>
                <input type="url"  class="field" id="orderWebsite" placeholder="ex. http://www.domain.com" />
            </li>
            <li class="telephone">
                <label for="orderTelephone">Your Phone Number</label>
                <input type="tel" id="orderTelephone"  class="field"
                    pattern="\(\d\d\d\) \d\d\d\-\d\d\d\d" title="(xxx) xxx-xxxx" />                
            </li>
             <li class="quantity">
                <label for="orderQty">Quantity</label>
                <input type="number" id="orderQty" name="orderQty" min=1 max=10 step=1 value=1 />
                x
                <span id="orderPrice">@string.Format("{0:f}", product.Price)</span>
                =
                <span id="orderTotal">@string.Format("{0:f}", product.Price)</span>
            </li>
            <div id="ship">
                <a id="switchToPickup">Interested in picking your order up at one of our stores?</a>
                <li class="requestedDate">
                    <label for="deliveryDate">Requested Delivery Date</label>
                    <input type="date" id="deliveryDate"  class="field" required />                
                </li>
                <li class="shipping">
                    <label for="orderShipping">Shipping Address</label>
                    <textarea rows="4" cols="20" id="orderShipping"  class="field" required></textarea>
                </li>
            </div>
            <div id="pickup">
                <a id="switchToShip">Want this order shipped to your door?</a>
                <div id="map"></div>
            </div>
             
           
        </ol>
        <div id="validationBlock">
            This form is currently <span id="validationState"></span>.
        </div>
        <p class="actions">
            <input type="hidden" name="ProductId" value="@product.Id" />
            <input type="submit" value="Place Order" />
            <input type="submit" formnovalidate value="Save for Later" id="saveForLater" />
        </p>
    </fieldset>
</form>

<script charset="UTF-8" type="text/javascript" src="http://ecn.dev.virtualearth.net/mapcontrol/mapcontrol.ashx?v=7.0"></script>
<script charset="UTF-8" type="text/javascript" src="/js/locateBakery.js"></script>
<script type="text/javascript">
    $(function() {        
        $('a#switchToPickup').click(function(event) {
            event.preventDefault();
            $('#ship').hide();
        
            Modernizr.load({
                test: Modernizr.geolocation,
                nope: '../js/geolocationShim.js',
                complete: function() {
                    locate();
                }
            });        
    
            $('#pickup').show();
            $('#map').show();
        });
    
        $('a#switchToShip').click(function(event) {
            event.preventDefault();
            $('#map').hide();
            $('#pickup').hide();
            $('#ship').show();
        });
    
        var price = parseFloat($("#orderPrice").text()).toFixed(2),
            total = $("#orderTotal"),
            orderQty = $("#orderQty");

        orderQty.change(function() {
            var quantity = parseInt(orderQty.val());
            orderQty.val(quantity);
            total.text("$" + (price * quantity).toFixed(2));
        });
        
        var saveToStorage = function() {
            var pendingOrder = {
                product: @productId,
                name: $("#orderName").val(),
                email: $("#orderEmail").val(),
                webSite: $("#orderWebsite").val(),
                phoneNumber: $("#orderTelephone").val(),
                address: $("#orderShipping").val()
            };
            
            window.localStorage.pendingOrder = JSON.stringify(pendingOrder);            
        };
        
        var loadFromStorage = function() {
            if (!window.localStorage.pendingOrder) {
                return;   
            }            
            
            var pendingOrder = JSON.parse(window.localStorage.pendingOrder);
            
            if (pendingOrder.product === @productId) {
                $("#orderName").val(pendingOrder.name);
                $("#orderEmail").val(pendingOrder.email);
                $("#orderWebsite").val(pendingOrder.webSite);
                $("#orderTelephone").val(pendingOrder.phoneNumber);
                $("#orderShipping").val(pendingOrder.address);            
            }
        };
        
        //DEMO: [Bonus] Use localStorage to save form data
        $("#saveForLater").click(function() {
            saveToStorage();
            
            $("input[type='submit']").attr('formnovalidate', 'formnovalidate');            
        });
        
        //DEMO :: Polyfill Forms Support
        Modernizr.load({
            test: Modernizr.input.placeholder,
            nope: "../js/html5placeholder.jquery.min.js",
            callback: function() {
                $('input[placeholder]').placeholder();
            }
        });
        
        //DEMO :: Polyfill Input Type Support
        if (!Modernizr.inputtypes.date) {
            $("input[type=date]").datepicker();
        }
        
        //DEMO :: Polyfill full forms support        
        if (!("noValidate" in document.createElement("form")))
        {
            $.getScript('../js/h5f.min.js', function() {
                H5F.setup($('#orderForm')[0], {
                    validClass: "valid",
                    invalidClass: "invalid",
                    requiredClass: "required",
                    placeholderClass: "placeholder"
                });
            });
        }
        
        loadFromStorage();
    });
</script>
